# -*- coding:Utf-8 -*-
#-------------------------------------------------------------------------------
# Name:        script_mapcycle.py
#
# Author:      Nico
#
# Created:     03/12/2007
#-------------------------------------------------------------------------------

import es, os, re

info = es.AddonInfo()
info.name = "script_mapcycle"
info.version = "1.1"
info.author = "Nicolous"
info.url = "http://mattie.info/forums/"
info.description = "Generate a mapcycle from your maps/ directory"
info.tags = "mapcycle;maps"

class Script_MapCycle:
    """script_mapcycle static variables and methods"""

    class ConVars:
        """Static intern class that contains the ConVars of the script"""
    
        # Public ConVar for monitoring which servers use the script
        es.ServerVar("mapcycle_version",info.version,info.name + " : Version of the MapCycle script").makepublic()
        # No reference is needed

        # If the script is activated
        MAPCYCLE_ACTIVATION = es.ServerVar("mapcycle_activation","1",info.name + " : 1 = activation, 0 = off")

        # File when the mapcycle will be generated
        MAPCYCLE_FILE = es.ServerVar("mapcycle_file","mapcycle.txt",info.name + " : 1 = activation, 0 = off")

    @staticmethod
    def getGameDir():
        """Return the game path, e.g. cstrike"""

        return es.getAddonPath(info.name).replace(os.sep,"/").replace("/addons/eventscripts/" + info.name,"")


class MapCycleGenerator:
    """Generate a mapcycle file from tour maps/ directory"""

    def __init__(self,pathFile):
        """Generate a mapcycle file in a specified file name"""

        BSP_PATTERN = re.compile(".*\.bsp$").search

        # Tring to open the destination file
        try:
            # Openning the file
            mapcycleFile = open(pathFile,"w")
            
            # Getting the files names of the maps/ directory
            maplist = os.listdir(self.__getMapsDirectory())

            # Keeping only the .bsp files
            maplist = filter(
                                lambda fileName:
                                    BSP_PATTERN(fileName)
                                ,
                                maplist
                            )

            # For each file...
            for fileName in maplist:
                # ... Writing the file name in the destination file
                mapcycleFile.write(os.path.splitext(fileName)[0] + "\n")

            # Forcing sorting of the list in alphabetic order
            maplist.sort()

            # Closing the file
            mapcycleFile.close()

        # If the file can not be writed
        except IOError:
            es.dbgmsg(0,info.name + " : Unable to write " + pathFile)

    @staticmethod
    def __getMapsDirectory():
        """Returns the maps/ path"""

        return Script_MapCycle.getGameDir() + "/maps"


def es_map_start(event_var):
    """ES function automatically called when a new map start"""

    # Immediatly execute the config file
    es.ForceServerCommand("es_mexec ../addons/eventscripts/script_mapcycle/configuration.txt")
    
    # If the script is activated, it updates the mapcyle file
    if bool(Script_MapCycle.ConVars.MAPCYCLE_ACTIVATION):
        MapCycleGenerator(Script_MapCycle.getGameDir() + "/" + str(Script_MapCycle.ConVars.MAPCYCLE_FILE))

